
<p align="center">
    EvO AutoML is a Python library for Evolution based Online AutoML.
    EvO AutoML ambition is to enable hyperparameter optimization for <a href="https://www.wikiwand.com/en/Online_machine_learning">online machine learning</a> pipelines build on <a href="https://riverml.xyz/latest/">river</a>.
</p>

# EvO AutoML

EvO AutoML is a Python library for Evolution based Online AutoML.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip install evoautoml
```
